==========================
バックアップとリストア
==========================

サービス定義の backup_scripts にバックアップの採取方法を指定することで、リポジトリサーバにバックアップを採取することができます。

バックアップファイルの保存先
-------------------------------
バックアップは毎日深夜1時にリポジトリサーバの ~/backup に backup-{name属性の値}-{採取日時}.{ext属性の値} という名前で保存されます。
また、最後に採取したバックアップに対して backup-{name属性の値}-latest.{ext属性の値}  という名前でシンボリックリンクが貼られます。
したがって、このディレクトリのからコピーすることで、外部のストレージにバックアップを保存することができます。
最後のバックアップをアーカイブするのであれば、リポジトリサーバで以下のコマンドを実行することで bakcup.tar.gz というファイルにまとめることができます。

::

  tar cvzhf backup.tar.gz backup/*-latest.*

リポジトリと監視データのバックアップ
--------------------------------------
リポジトリサーバで動作しているリポジトリサービスと監視サービスのデータもバックアップが採取されます。
このときのサービス名は hive-registry と hive-zabbix です。

リストア方法
-------------------------------
リポジトリサーバの ~/backup に各サービスの latest のバックアップが置かれていれば、以下のコマンドでデータをリストアできます。

 ::

   hive-backup.sh  -r

サービスごとに個別にリストアする場合は、 -l オプションでサービス名を指定します。
例えば、pdnsdb サービスのデータとリポジトリサーバの zabbix のデータをリストアする場合は以下のコマンドになります。

 ::

   hive-backup.sh  -r -l pdnsdb,hive-zabbix

個別バックアップの採取
-------------------------------
深夜1時の日次バッチ以外のタイミイングでバックアップを採取する場合、リポジトリサーバで以下のコマンドを実行してバックアップを採取できます。

 ::

   hive-backup.sh

このコマンドで~/backup にすべてのサービスのバックアップを採取します。
サービスごとに個別にバックアップを採取する場合は、 -l オプションでサービス名を指定します。
例えば、pdnsdb サービスのデータとリポジトリサーバの zabbix のデータをバックアップする場合は以下のコマンドになります。

 ::

   hive-backup.sh  -l pdnsdb,hive-zabbix

